@@ -4,7 +4,7 @@ mod commands;
 fn main() {
     if let Err(error) = cli::main() {
         if let Some(inner_error) = error.error {
-            println!("{}", inner_error);
+            eprintln!("{}", inner_error);
         }
         std::process::exit(error.exit_code);
     }
